searchNodes=[{"doc":"ExAws.S3.Crypto provides client-side encryption support for Amazon S3 . It allows you to encrypt data before sending it to S3. This particular implementation currently supports a AWS KMS-managed customer master key and assumes you have one already generated. This library makes heavy use of the existing ex_aws_s3 library and Erlang's crypto module . It has confirmed compatability with the Golang AWS SDK client-encryption library and uses AES GCM with 256-bit keys by default. Examples First, make sure you have the id for your master key (should be of the form of a UUID, like 123e4567-e89b-12d3-a456-426655440000 ) and the bucket you're using already set up. You should be able to make requests using ExAws (see the ExAws docs for configuration instructions). To encrypt and upload an object, it's easy as pie. bucket = &quot;my-awesome-bucket&quot; key_id = &quot;123e4567-e89b-12d3-a456-426655440000&quot; contents = &quot;this is some special text that should be secret&quot; # Encrypt, then upload object request = ExAws.S3 . put_object ( bucket , &quot;secret.txt.enc&quot; , contents ) { :ok , encrypted_request } = ExAws.S3.Crypto . encrypt ( request , key_id ) ExAws . request ( encrypted_request ) # Or, use this shorter version of above ExAws.S3.Crypto . put_encrypted_object ( bucket , &quot;secret.txt.enc&quot; , contents , key_id ) Decrypting is easy too, and doesn't even require knowing the original key id. # get encrypted object, then decrypt { :ok , encrypted } = ExAws.S3 . get_object ( bucket , &quot;secret.txt.enc&quot; ) |&gt; ExAws . request { :ok , decrypted } = ExAws.S3.Crypto . decrypt ( encrypted ) IO . puts decrypted . body # Or, use this shorter version of above { :ok , decrypted } = ExAws.S3.Crypto . get_encrypted_object ( bucket , &quot;secret.txt.enc&quot; ) IO . puts decrypted . body","ref":"ExAws.S3.Crypto.html","title":"ExAws.S3.Crypto","type":"module"},{"doc":"Take the result of a ExAws.S3.get_object/3 and replace the body with the decrypted value. For example: bucket = &quot;my-awesome-bucket&quot; key_id = &quot;123e4567-e89b-12d3-a456-426655440000&quot; # get encrypted object, then decrypt { :ok , encrypted } = ExAws.S3 . get_object ( bucket , &quot;secret.txt.enc&quot; ) |&gt; ExAws . request { :ok , decrypted } = ExAws.S3.Crypto . decrypt ( encrypted ) IO . puts decrypted . body","ref":"ExAws.S3.Crypto.html#decrypt/1","title":"ExAws.S3.Crypto.decrypt/1","type":"function"},{"doc":"Modify a ExAws.Operation.S3 put operation by encrypting the body with a key generated from KMS using the given master key_id. For example: bucket = &quot;my-awesome-bucket&quot; key_id = &quot;123e4567-e89b-12d3-a456-426655440000&quot; contents = &quot;this is some special text that should be secret&quot; # Encrypt, then upload object request = ExAws.S3 . put_object ( bucket , &quot;secret.txt.enc&quot; , contents ) { :ok , encrypted_request } = ExAws.S3.Crypto . encrypt ( request , key_id ) ExAws . request ( encrypted_request )","ref":"ExAws.S3.Crypto.html#encrypt/3","title":"ExAws.S3.Crypto.encrypt/3","type":"function"},{"doc":"Get an object from a bucket and then decrypt the body. This merely wraps sending a ExAws.S3.get_object/3 request and then calling decrypt/1 with the results. For example: { :ok , decrypted } = ExAws.S3.Crypto . get_encrypted_object ( &quot;my-awesome-bucket&quot; , &quot;secret.txt.enc&quot; ) IO . puts decrypted . body","ref":"ExAws.S3.Crypto.html#get_encrypted_object/3","title":"ExAws.S3.Crypto.get_encrypted_object/3","type":"function"},{"doc":"Encrypt and then create an object within a bucket. This merely wraps creating a ExAws.Operation.S3 request, calling encrypt/3 , and uploading to S3 via a call to ExAws.request/1 . For example: bucket = &quot;my-awesome-bucket&quot; key_id = &quot;123e4567-e89b-12d3-a456-426655440000&quot; contents = &quot;this is some special text that should be secret&quot; ExAws.S3.Crypto . put_encrypted_object ( bucket , &quot;secret.txt.enc&quot; , contents , key_id )","ref":"ExAws.S3.Crypto.html#put_encrypted_object/5","title":"ExAws.S3.Crypto.put_encrypted_object/5","type":"function"},{"doc":"","ref":"ExAws.S3.Crypto.html#t:encrypt_opts/0","title":"ExAws.S3.Crypto.encrypt_opts/0","type":"type"},{"doc":"","ref":"ExAws.S3.Crypto.html#t:supported_cipher/0","title":"ExAws.S3.Crypto.supported_cipher/0","type":"type"},{"doc":"This module wraps the logic necessary to encrypt / decrypt using AES GCM . See the Erlang docs for crypto_one_time_aead for more info.","ref":"ExAws.S3.Crypto.AESGCMCipher.html","title":"ExAws.S3.Crypto.AESGCMCipher","type":"module"},{"doc":"Decrypt the given contents with the supplied key and initialization vector.","ref":"ExAws.S3.Crypto.AESGCMCipher.html#decrypt/3","title":"ExAws.S3.Crypto.AESGCMCipher.decrypt/3","type":"function"},{"doc":"Encrypt the given contents with the supplied key.","ref":"ExAws.S3.Crypto.AESGCMCipher.html#encrypt/2","title":"ExAws.S3.Crypto.AESGCMCipher.encrypt/2","type":"function"},{"doc":"Utility module to wrap calls to ExAws.KMS to generate / decrypt data keys .","ref":"ExAws.S3.Crypto.KMSWrapper.html","title":"ExAws.S3.Crypto.KMSWrapper","type":"module"},{"doc":"Decrypt an encrypted data key . The context is an encryption context that should generally just be a map of %{&quot;kms_cmk_id&quot; =&gt; key_id} for the master key_id used in the initial generation.","ref":"ExAws.S3.Crypto.KMSWrapper.html#decrypt_key/2","title":"ExAws.S3.Crypto.KMSWrapper.decrypt_key/2","type":"function"},{"doc":"Generate a data key for the master key with the given id.","ref":"ExAws.S3.Crypto.KMSWrapper.html#generate_data_key/1","title":"ExAws.S3.Crypto.KMSWrapper.generate_data_key/1","type":"function"}]